/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
    var __webpack_exports__ = {};

    if (chrome.browserAction) {
        chrome.browserAction.onClicked.addListener(tab => {
            console.log('Browser action clicked'); // 追加
            //show/hide the pie when the user clicks on the toolbar icon
            chrome.tabs.sendMessage(tab.id, {
                toggle: true
            });
        });
    }


    chrome.runtime.onMessage.addListener(function (request, sender, sendResponse) {
        if (request.type === "getTabId") {
            //console.log("return tabid:", sender.tab.id);
            sendResponse({ tabId: sender.tab.id });
        } else if (request.type === 'switchTab') {
            switchTab(sender.tab.id, request.direction);
        } else if (request.type === 'closeTab') {
            // タブを閉じる
            chrome.tabs.query({ active: true, currentWindow: true }, function (tabs) {
                chrome.tabs.remove(tabs[0].id);
            });
        } else if (request.type === 'openOptionsPage') {

            // オプションページの URL を取得
            const optionsPageUrl = chrome.runtime.getManifest().options_page;
            console.log('openOptionsPage url:', optionsPageUrl);

            // 既存のタブがオプションページを表示しているか確認
            let createTab = false;
            const extensionId = chrome.runtime.id;
            chrome.tabs.query({}, async function (tabs) {
                //chrome.tabs.query({ url: optionsPageUrl }, function (tabs) {
                console.log("tabs:", tabs);
                for (let i = 0; i < tabs.length; i++) {
                    if (tabs[i].url &&
                        tabs[i].url.includes(extensionId) &&
                        tabs[i].url.includes(optionsPageUrl)
                    ) {
                        // 既に開いている場合はそのタブに切り替え
                        chrome.tabs.update(tabs[i].id, { active: true });
                        return;
                    }
                }
                chrome.tabs.create({ url: optionsPageUrl });
            });
        }
    });


    // タブ切り替え関数
    function switchTab(currentTabId, direction) {
        chrome.tabs.query({}, async function (tabs) {
            const nextTabId = await findNextExtensionTab(currentTabId, direction, tabs);
            if (nextTabId) {
                //console.log(`Next tab's id: ${nextTabId}`);
                chrome.tabs.update(nextTabId, { active: true });
            } else {
                console.log(`No matching extension tab found.`);
            }
        });
    }


    // 次の拡張機能で生成されたタブを検索する関数
    async function findNextExtensionTab(currentTabId, direction, tabs) {
        const extensionTabs = tabs.filter(tab => isExtensionTab(tab));

        let firstaTabId = 0;
        let lastTabId = 0;
        for (let i = 0; i < extensionTabs.length; i++) {
            if (!firstaTabId && extensionTabs[i].url.includes("http")) {
                firstaTabId = extensionTabs[i].id;
            }
            lastTabId = extensionTabs[i].id;
        }
        console.log("firstaTabId:", firstaTabId);
        console.log("lastTabId:", lastTabId);

        let nextTabId;
        for (let i = 0; i < extensionTabs.length; i++) {
            if (extensionTabs[i].id === currentTabId) {
                console.log("search tab i=", i);
                // 指定された tabId と一致した場合
                if (direction === 'next') {
                    if (i == extensionTabs.length - 1) {
                        // 最後のタブでnext押下時
                        nextTabId = firstaTabId;
                    }
                    else {
                        // 次のタブの id を取得
                        nextTabId = extensionTabs[(i + 1) % extensionTabs.length].id;
                    }
                } else if (direction === 'previous') {
                    if (extensionTabs[i].id == firstaTabId) {
                        nextTabId = lastTabId;
                    }
                    else {
                        // 前のタブの id を取得
                        nextTabId = extensionTabs[(i - 1 + extensionTabs.length) % extensionTabs.length].id;
                    }
                }
                const settingId = await getSettingId(nextTabId);
                console.log("nextTabId:", nextTabId);
                console.log("settingId:", settingId);
                if (settingId == 0) {
                    nextTabId = 0;
                }
                else {
                    break;
                }
            }
        }
        return nextTabId;
    }


    async function getSettingId(tabId) {
        return new Promise((resolve) => {
            chrome.storage.local.get([`settingId_${tabId}`], (data) => {
                const settingId = data[`settingId_${tabId}`];
                resolve(settingId !== undefined ? settingId : 0);
            });
        });
    }


    // 拡張機能で生成されたタブであるかを判定する関数
    function isExtensionTab(tab) {
        // ここでは settingId が 0 ではない場合を拡張機能で生成されたタブと判定する
        return getSettingId(tab.id) !== 0;
    }

    // タブ削除
    chrome.tabs.onRemoved.addListener(tabId => {
        console.log("chrome.tabs.onRemoved");
        chrome.storage.local.remove(`settingId_${tabId}`);
    });


    // popup画面起動
    chrome.runtime.onMessage.addListener(function (request, sender, sendResponse) {
        if (request.action === "openPopup") {
            // ポップアップを開く処理
            console.log("popup");
            chrome.tabs.create({ "url": "popup.html" });
        }
    });





})();

